summaryrefslogtreecommitdiff
path: root/nuttx/configs/twr-k60n512/src
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-01-25 20:17:59 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-01-25 20:17:59 +0000
commit657f0d2092b325bbaec6d61cce725295e38df61e (patch)
tree7dddd582f892fceb4d2b93f1202946d7cbeed23b /nuttx/configs/twr-k60n512/src
parenta2067c2d2efa28d2f252bec2893c470733935049 (diff)
downloadpx4-nuttx-657f0d2092b325bbaec6d61cce725295e38df61e.tar.gz
px4-nuttx-657f0d2092b325bbaec6d61cce725295e38df61e.tar.bz2
px4-nuttx-657f0d2092b325bbaec6d61cce725295e38df61e.zip
Massive name change USB STRG -> USB MSC
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@4334 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/configs/twr-k60n512/src')
-rw-r--r--nuttx/configs/twr-k60n512/src/Makefile4
-rw-r--r--nuttx/configs/twr-k60n512/src/up_usbmsc.c (renamed from nuttx/configs/twr-k60n512/src/up_usbstrg.c)16
2 files changed, 10 insertions, 10 deletions
diff --git a/nuttx/configs/twr-k60n512/src/Makefile b/nuttx/configs/twr-k60n512/src/Makefile
index 4a5e743b7..18a9c118f 100644
--- a/nuttx/configs/twr-k60n512/src/Makefile
+++ b/nuttx/configs/twr-k60n512/src/Makefile
@@ -58,8 +58,8 @@ ifeq ($(CONFIG_USBDEV),y)
CSRCS += up_usbdev.c
endif
-ifeq ($(CONFIG_USBSTRG),y)
-CSRCS += up_usbstrg.c
+ifeq ($(CONFIG_USBMSC),y)
+CSRCS += up_usbmsc.c
endif
COBJS = $(CSRCS:.c=$(OBJEXT))
diff --git a/nuttx/configs/twr-k60n512/src/up_usbstrg.c b/nuttx/configs/twr-k60n512/src/up_usbmsc.c
index cdc373205..bebedd02f 100644
--- a/nuttx/configs/twr-k60n512/src/up_usbstrg.c
+++ b/nuttx/configs/twr-k60n512/src/up_usbmsc.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * configs/twr-k60n512/src/up_usbstrg.c
+ * configs/twr-k60n512/src/up_usbmsc.c
*
* Copyright (C) 2011 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <spudmonkey@racsa.co.cr>
@@ -56,8 +56,8 @@
/* Configuration ************************************************************/
-#ifndef CONFIG_EXAMPLES_USBSTRG_DEVMINOR1
-# define CONFIG_EXAMPLES_USBSTRG_DEVMINOR1 0
+#ifndef CONFIG_EXAMPLES_USBMSC_DEVMINOR1
+# define CONFIG_EXAMPLES_USBMSC_DEVMINOR1 0
#endif
/* SLOT number(s) could depend on the board configuration */
@@ -96,23 +96,23 @@
****************************************************************************/
/****************************************************************************
- * Name: usbstrg_archinitialize
+ * Name: usbmsc_archinitialize
*
* Description:
* Perform architecture specific initialization
*
****************************************************************************/
-int usbstrg_archinitialize(void)
+int usbmsc_archinitialize(void)
{
/* If examples/usbstrg is built as an NSH command, then SD slot should
* already have been initized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.
*/
-#ifndef CONFIG_EXAMPLES_USBSTRG_BUILTIN
+#ifndef CONFIG_EXAMPLES_USBMSC_BUILTIN
# warning "Missing logic"
-#endif /* CONFIG_EXAMPLES_USBSTRG_BUILTIN */
+#endif /* CONFIG_EXAMPLES_USBMSC_BUILTIN */
return OK;
}
@@ -96,23 +96,23 @@
{
- /* If examples/usbstrg is built as an NSH command, then SD slot should
+ /* If examples/usbmsc is built as an NSH command, then SD slot should
* already have been initized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.